import type { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import type { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import type { Listener, Provider } from "@ethersproject/providers";
import type { TypedEventFilter, TypedEvent, TypedListener, OnEvent, PromiseOrValue } from "./common";
export interface TornadoProxyInterface extends utils.Interface {
    functions: {
        "bulkResolve(bytes32[])": FunctionFragment;
        "governance()": FunctionFragment;
        "instances(address)": FunctionFragment;
        "resolve(bytes32)": FunctionFragment;
        "tornadoTrees()": FunctionFragment;
        "deposit(address,bytes32,bytes)": FunctionFragment;
        "updateInstance(address,bool)": FunctionFragment;
        "withdraw(address,bytes,bytes32,bytes32,address,address,uint256,uint256)": FunctionFragment;
        "rescueTokens(address,address,uint256)": FunctionFragment;
    };
    getFunction(nameOrSignatureOrTopic: "bulkResolve" | "governance" | "instances" | "resolve" | "tornadoTrees" | "deposit" | "updateInstance" | "withdraw" | "rescueTokens"): FunctionFragment;
    encodeFunctionData(functionFragment: "bulkResolve", values: [PromiseOrValue<BytesLike>[]]): string;
    encodeFunctionData(functionFragment: "governance", values?: undefined): string;
    encodeFunctionData(functionFragment: "instances", values: [PromiseOrValue<string>]): string;
    encodeFunctionData(functionFragment: "resolve", values: [PromiseOrValue<BytesLike>]): string;
    encodeFunctionData(functionFragment: "tornadoTrees", values?: undefined): string;
    encodeFunctionData(functionFragment: "deposit", values: [
        PromiseOrValue<string>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BytesLike>
    ]): string;
    encodeFunctionData(functionFragment: "updateInstance", values: [PromiseOrValue<string>, PromiseOrValue<boolean>]): string;
    encodeFunctionData(functionFragment: "withdraw", values: [
        PromiseOrValue<string>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<BytesLike>,
        PromiseOrValue<string>,
        PromiseOrValue<string>,
        PromiseOrValue<BigNumberish>,
        PromiseOrValue<BigNumberish>
    ]): string;
    encodeFunctionData(functionFragment: "rescueTokens", values: [
        PromiseOrValue<string>,
        PromiseOrValue<string>,
        PromiseOrValue<BigNumberish>
    ]): string;
    decodeFunctionResult(functionFragment: "bulkResolve", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "governance", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "instances", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "resolve", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "tornadoTrees", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "deposit", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "updateInstance", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "withdraw", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "rescueTokens", data: BytesLike): Result;
    events: {
        "EncryptedNote(address,bytes)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "EncryptedNote"): EventFragment;
}
export interface EncryptedNoteEventObject {
    sender: string;
    encryptedNote: string;
}
export type EncryptedNoteEvent = TypedEvent<[
    string,
    string
], EncryptedNoteEventObject>;
export type EncryptedNoteEventFilter = TypedEventFilter<EncryptedNoteEvent>;
export interface TornadoProxy extends BaseContract {
    contractName: "TornadoProxy";
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: TornadoProxyInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        bulkResolve(domains: PromiseOrValue<BytesLike>[], overrides?: CallOverrides): Promise<[string[]] & {
            result: string[];
        }>;
        governance(overrides?: CallOverrides): Promise<[string]>;
        instances(arg0: PromiseOrValue<string>, overrides?: CallOverrides): Promise<[boolean]>;
        resolve(node: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<[string]>;
        tornadoTrees(overrides?: CallOverrides): Promise<[string]>;
        deposit(_tornado: PromiseOrValue<string>, _commitment: PromiseOrValue<BytesLike>, _encryptedNote: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        updateInstance(_instance: PromiseOrValue<string>, _update: PromiseOrValue<boolean>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        withdraw(_tornado: PromiseOrValue<string>, _proof: PromiseOrValue<BytesLike>, _root: PromiseOrValue<BytesLike>, _nullifierHash: PromiseOrValue<BytesLike>, _recipient: PromiseOrValue<string>, _relayer: PromiseOrValue<string>, _fee: PromiseOrValue<BigNumberish>, _refund: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
        rescueTokens(_token: PromiseOrValue<string>, _to: PromiseOrValue<string>, _balance: PromiseOrValue<BigNumberish>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<ContractTransaction>;
    };
    bulkResolve(domains: PromiseOrValue<BytesLike>[], overrides?: CallOverrides): Promise<string[]>;
    governance(overrides?: CallOverrides): Promise<string>;
    instances(arg0: PromiseOrValue<string>, overrides?: CallOverrides): Promise<boolean>;
    resolve(node: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<string>;
    tornadoTrees(overrides?: CallOverrides): Promise<string>;
    deposit(_tornado: PromiseOrValue<string>, _commitment: PromiseOrValue<BytesLike>, _encryptedNote: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    updateInstance(_instance: PromiseOrValue<string>, _update: PromiseOrValue<boolean>, overrides?: Overrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    withdraw(_tornado: PromiseOrValue<string>, _proof: PromiseOrValue<BytesLike>, _root: PromiseOrValue<BytesLike>, _nullifierHash: PromiseOrValue<BytesLike>, _recipient: PromiseOrValue<string>, _relayer: PromiseOrValue<string>, _fee: PromiseOrValue<BigNumberish>, _refund: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    rescueTokens(_token: PromiseOrValue<string>, _to: PromiseOrValue<string>, _balance: PromiseOrValue<BigNumberish>, overrides?: Overrides & {
        from?: PromiseOrValue<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        bulkResolve(domains: PromiseOrValue<BytesLike>[], overrides?: CallOverrides): Promise<string[]>;
        governance(overrides?: CallOverrides): Promise<string>;
        instances(arg0: PromiseOrValue<string>, overrides?: CallOverrides): Promise<boolean>;
        resolve(node: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<string>;
        tornadoTrees(overrides?: CallOverrides): Promise<string>;
        deposit(_tornado: PromiseOrValue<string>, _commitment: PromiseOrValue<BytesLike>, _encryptedNote: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<void>;
        updateInstance(_instance: PromiseOrValue<string>, _update: PromiseOrValue<boolean>, overrides?: CallOverrides): Promise<void>;
        withdraw(_tornado: PromiseOrValue<string>, _proof: PromiseOrValue<BytesLike>, _root: PromiseOrValue<BytesLike>, _nullifierHash: PromiseOrValue<BytesLike>, _recipient: PromiseOrValue<string>, _relayer: PromiseOrValue<string>, _fee: PromiseOrValue<BigNumberish>, _refund: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<void>;
        rescueTokens(_token: PromiseOrValue<string>, _to: PromiseOrValue<string>, _balance: PromiseOrValue<BigNumberish>, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "EncryptedNote(address,bytes)"(sender?: PromiseOrValue<string> | null, encryptedNote?: null): EncryptedNoteEventFilter;
        EncryptedNote(sender?: PromiseOrValue<string> | null, encryptedNote?: null): EncryptedNoteEventFilter;
    };
    estimateGas: {
        bulkResolve(domains: PromiseOrValue<BytesLike>[], overrides?: CallOverrides): Promise<BigNumber>;
        governance(overrides?: CallOverrides): Promise<BigNumber>;
        instances(arg0: PromiseOrValue<string>, overrides?: CallOverrides): Promise<BigNumber>;
        resolve(node: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<BigNumber>;
        tornadoTrees(overrides?: CallOverrides): Promise<BigNumber>;
        deposit(_tornado: PromiseOrValue<string>, _commitment: PromiseOrValue<BytesLike>, _encryptedNote: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        updateInstance(_instance: PromiseOrValue<string>, _update: PromiseOrValue<boolean>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        withdraw(_tornado: PromiseOrValue<string>, _proof: PromiseOrValue<BytesLike>, _root: PromiseOrValue<BytesLike>, _nullifierHash: PromiseOrValue<BytesLike>, _recipient: PromiseOrValue<string>, _relayer: PromiseOrValue<string>, _fee: PromiseOrValue<BigNumberish>, _refund: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
        rescueTokens(_token: PromiseOrValue<string>, _to: PromiseOrValue<string>, _balance: PromiseOrValue<BigNumberish>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        bulkResolve(domains: PromiseOrValue<BytesLike>[], overrides?: CallOverrides): Promise<PopulatedTransaction>;
        governance(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        instances(arg0: PromiseOrValue<string>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        resolve(node: PromiseOrValue<BytesLike>, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        tornadoTrees(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        deposit(_tornado: PromiseOrValue<string>, _commitment: PromiseOrValue<BytesLike>, _encryptedNote: PromiseOrValue<BytesLike>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        updateInstance(_instance: PromiseOrValue<string>, _update: PromiseOrValue<boolean>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        withdraw(_tornado: PromiseOrValue<string>, _proof: PromiseOrValue<BytesLike>, _root: PromiseOrValue<BytesLike>, _nullifierHash: PromiseOrValue<BytesLike>, _recipient: PromiseOrValue<string>, _relayer: PromiseOrValue<string>, _fee: PromiseOrValue<BigNumberish>, _refund: PromiseOrValue<BigNumberish>, overrides?: PayableOverrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
        rescueTokens(_token: PromiseOrValue<string>, _to: PromiseOrValue<string>, _balance: PromiseOrValue<BigNumberish>, overrides?: Overrides & {
            from?: PromiseOrValue<string>;
        }): Promise<PopulatedTransaction>;
    };
}
//# sourceMappingURL=TornadoProxy.d.ts.map