import { DeepRequired, Merge } from 'ts-essentials';
import { Provider } from '@ethersproject/providers';
import { EventFilter } from 'ethers';
import { RelayerRegistry } from './deth/RelayerRegistry.js';
import { AsyncUtils } from '@tornado/sdk-utils';
import { Docs, Cache, Options as DataOptions } from '@tornado/sdk-data';
import { Chain, Synchronizer, Options as ChainOptions } from '@tornado/sdk-chain';
export declare namespace Options {
    type Cache = DataOptions.Cache;
    type Sync = ChainOptions.Sync;
}
export declare class Registration extends Docs.Base {
    ensName: string;
    address: string;
    relayer: string;
    stakedAmount: string;
    constructor(obj: any);
}
export declare class Stake extends Docs.Base {
    relayer: string;
    amountStakeAdded: string;
    constructor(obj: any);
}
export declare class Burn extends Docs.Base {
    relayer: string;
    amountBurned: string;
    constructor(obj: any);
}
export declare class RegistrationsCache extends Cache.Syncable<Registration> {
    buildDoc(response: any): Registration;
    getErrorHandlers(): Array<AsyncUtils.ErrorHandler>;
    getCallbacks(registry: RelayerRegistry): Array<AsyncUtils.Callback>;
}
export declare class StakesCache extends Cache.Syncable<Stake> {
    buildDoc(response: any): Stake;
    getErrorHandlers(): Array<AsyncUtils.ErrorHandler>;
    getCallbacks(registry: RelayerRegistry): Array<AsyncUtils.Callback>;
}
export declare class BurnsCache extends Cache.Syncable<Burn> {
    buildDoc(response: any): Burn;
    getErrorHandlers(): Array<AsyncUtils.ErrorHandler>;
    getCallbacks(registry: RelayerRegistry): Array<AsyncUtils.Callback>;
}
export declare class Registry extends Synchronizer {
    private _chain?;
    get chain(): Chain;
    constructor();
    private _checkProvider;
    connect(provider: Provider): Promise<void>;
    getContract(): RelayerRegistry;
    syncRegistrations(networkId?: string | number, options?: Merge<Options.Sync, Options.Cache>): Promise<void>;
    syncStakes(networkId?: string | number, options?: Merge<Options.Sync, Options.Cache>): Promise<void>;
    syncBurns(networkId?: string | number, options?: Merge<Options.Sync, Options.Cache>): Promise<void>;
    protected _sync(event: string | EventFilter, networkId?: string | number, options?: Merge<Options.Sync, Options.Cache>): Promise<void>;
    loadRegistrations(networkId?: number | string, options?: Options.Cache): RegistrationsCache;
    loadStakes(networkId?: number | string, options?: Options.Cache): StakesCache;
    loadBurns(networkId?: number | string, options?: Options.Cache): BurnsCache;
    loadCache<D extends Docs.Base, C extends Cache.Syncable<D> = Cache.Syncable<D>>(name: string, options?: Options.Cache): C;
    exportRegistrationsZip(networkId?: number | string, outDirPath?: string, close?: boolean, options?: Options.Cache): Promise<void>;
    exportStakesZip(networkId?: number | string, outDirPath?: string, close?: boolean, options?: Options.Cache): Promise<void>;
    exportBurnsZip(networkId?: number | string, outDirPath?: string, close?: boolean, options?: Options.Cache): Promise<void>;
    exportRegistrationsJson(networkId?: number | string, outDirPath?: string, close?: boolean, options?: Options.Cache): Promise<void>;
    exportStakesJson(networkId?: number | string, outDirPath?: string, close?: boolean, options?: Options.Cache): Promise<void>;
    exportBurnsJson(networkId?: number | string, outDirPath?: string, close?: boolean, options?: Options.Cache): Promise<void>;
    protected _exportCacheZip(cacheName: string, outDirPath?: string, close?: boolean, options?: Options.Cache): Promise<void>;
    protected _exportCacheJson(cacheName: string, outDirPath?: string, close?: boolean, options?: Options.Cache): Promise<void>;
    protected _populateSyncOptions(options: Options.Sync): Promise<DeepRequired<Options.Sync>>;
}
//# sourceMappingURL=index.d.ts.map